% Calculate Sorted error plots for SCO data
clc;clear all;
symbols = {'@', 'A', 'C', 'D', 'E', 'G', 'I', 'J', 'O', 'R', 'S', 'T', 'U',...
    'W', 'Y', 'Z', 'a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i', 'k', 'l',...
    'm', 'n', 'o', 'p', 'r', 's', 't', 'u', 'v', 'w', 'y', 'z'}

CONS = {'C','D','G','J','S','T','Z','b','d','f','g','h','k','L','m','n','p','r','s','t','v','w','y','z'};
VOWS = {'@','A','E','I','O','R','U','W','Y','a','c','e','i','o','u'};
READING_DISABLED = {'Alina','Angela','Edward','Latisha','Laura','Norene','Shauna','Teddy','Tony'};

addpath ../bin
Colors=setAndreaColors;

% get usbject names
d=dir('../*.mat')


for sbj = 1 : length(d)
    mat_name = d(sbj).name
    load(['../' mat_name]);
    SBJS{1,sbj} =  mat_name(6:length(mat_name)-4);
    
    error_cons = zeros(2,length(CONS));
    n_cons = zeros(2,length(CONS));
    error_vows = zeros(2,length(VOWS));
    n_vows = zeros(2,length(VOWS));
    
    for trial = 1 : length(data)
        % Was first or second sound changed?
        if ~strcmp(data(trial).tgt1,data(trial).msk1)
            pos = 1; % inital was changed
            % VOW in inital position?
            vow_pos = find(strcmp(data(trial).tgt1,VOWS));
            if  ~isempty(vow_pos)
                if data(trial).score == 0
                    error_vows(pos,vow_pos) = error_vows(pos,vow_pos) + 1;
                end
                n_vows(pos,vow_pos) = n_vows(pos,vow_pos) + 1;
            else
                con_pos = find(strcmp(data(trial).tgt1,CONS));
                if data(trial).score == 0
                    error_cons(pos,con_pos) = error_cons(pos,con_pos) + 1;
                end
                n_cons(pos,con_pos) = n_cons(pos,con_pos) + 1;
            end
        else
            pos = 2; % final postion changed
            % VOW in final position?
            vow_pos = find(strcmp(data(trial).tgt1,VOWS));
            if  ~isempty(vow_pos)
                if data(trial).score == 0
                    error_vows(pos,vow_pos) = error_vows(pos,vow_pos) + 1;
                end
                n_vows(pos,vow_pos) = n_vows(pos,vow_pos) + 1;
            else
                con_pos = find(strcmp(data(trial).tgt1,CONS));
                if data(trial).score == 0
                    error_cons(pos,con_pos) = error_cons(pos,con_pos) + 1;
                end
                n_cons(pos,con_pos) = n_cons(pos,con_pos) + 1;
            end
        end
    end
    
    pe_cons = error_cons./n_cons;
    pe_cons(3,:) = sum(error_cons)./sum(n_cons);
    pe_vows = error_vows./n_vows;
    pe_vows(3,:) = sum(error_vows)./sum(n_vows);
    pe_allsbjs{1,sbj}=pe_vows;
    pe_allsbjs{2,sbj}=pe_cons;
end
for sbj = 1 : length(SBJS)
    if isempty(find(strcmp(SBJS{sbj},READING_DISABLED)))
        line_type = '-';
    else
        line_type = '--';
    end
    figure(1);hold on;
    subfig(221)
    title('Sorted Error Vowels Initial')
    pe_list = pe_allsbjs{1,sbj};
    pe_list_sort = sort(pe_list(1,:));
    plot(pe_list_sort,line_type,'color',Colors(sbj,:)./255)
    subfigure(222);hold on;
    title('Sorted Error Vowels Final')
    pe_list_sort = sort(pe_list(2,:));
    plot(pe_list_sort,line_type,'color',Colors(sbj,:)./255);
    figure(2); hold on;
    title('Sorted Error Vowels')
    pe_list_sort = sort(pe_list(3,:));
    plot(pe_list_sort,line_type,'color',Colors(sbj,:)./255)
    
    figure(1);subfigure(223);hold on;
    title('Sorted Error Consonants Initial')
    pe_list = pe_allsbjs{2,sbj};
    pe_list_sort = sort(pe_list(1,:));
    plot(pe_list_sort,line_type,'color',Colors(sbj,:)./255)
    subfigure(224);hold on;
    title('Sorted Error Consonants Final')
    pe_list_sort = sort(pe_list(2,:));
    plot(pe_list_sort,line_type,'color',Colors(sbj,:)./255);
    figure(2); hold on;
    title('Sorted Error Consonants')
    pe_list_sort = sort(pe_list(3,:));
    plot(pe_list_sort,line_type,'color',Colors(sbj,:)./255)
end
figure(1)
legend(SBJS,'Location','EastOutside')
fname = sprintf('vowels_initial.eps'); % figure name
print(gcf, fullfile('fig', fname), '-depsc2'); % save stacked barplot
figure(2)
legend(SBJS,'Location','EastOutside')
fname = sprintf('vowels_final.eps'); % figure name
print(gcf, fullfile('fig', fname), '-depsc2'); % save stacked barplot
figure(3)
legend(SBJS,'Location','EastOutside')
fname = sprintf('vowels_together.eps'); % figure name
print(gcf, fullfile('fig', fname), '-depsc2'); % save stacked barplot
figure(4)
legend(SBJS,'Location','EastOutside')
fname = sprintf('cons_initial.eps'); % figure name
print(gcf, fullfile('fig', fname), '-depsc2'); % save stacked barplot
figure(5)
legend(SBJS,'Location','EastOutside')
fname = sprintf('cons_final.eps'); % figure name
print(gcf, fullfile('fig', fname), '-depsc2'); % save stacked barplot
figure(6)
legend(SBJS,'Location','EastOutside')
fname = sprintf('cons_together.eps'); % figure name
print(gcf, fullfile('fig', fname), '-depsc2'); % save stacked barplot
