% Calculate Sorted error plots for SCO data
clc;clear all; close all;
symbols = {'@', 'A', 'C', 'D', 'E', 'G', 'I', 'J', 'O', 'R', 'S', 'T', 'U',...
    'W', 'Y', 'Z', 'a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i', 'k', 'l',...
    'm', 'n', 'o', 'p', 'r', 's', 't', 'u', 'v', 'w', 'y', 'z'}

CONS = {'C','D','G','J','S','T','Z','b','d','f','g','h','k','L','m','n','p','r','s','t','v','w','y','z'};
VOWS = {'@','A','E','I','O','R','U','W','Y','a','c','e','i','o','u'};
READING_DISABLED = {'Alina','Angela','Edward','Latisha','Laura','Matt','Norene','Shauna','Tina','Teddy','Tony'};

Nt = 10; % threshold for number of trails


addpath ../bin
addpath ./bin
Colors=setAndreaColors;

% get usbject names
d=dir('../*.mat')


for sbj = 1 : length(d)
    mat_name = d(sbj).name
    load(['../' mat_name]);
    SBJS{1,sbj} =  mat_name(6:length(mat_name)-4);
    
    error_cons = zeros(2,length(CONS));
    n_cons = zeros(2,length(CONS));
    error_vows = zeros(2,length(VOWS));
    n_vows = zeros(2,length(VOWS));
    
    for trial = 1 : length(data)
        % Was first or second sound changed?
        if ~strcmp(data(trial).tgt1,data(trial).msk1)
            pos = 1; % inital was changed
            % VOW in inital position?
            vow_pos = find(strcmp(data(trial).tgt1,VOWS));
            if  ~isempty(vow_pos)
                if data(trial).score == 0
                    error_vows(pos,vow_pos) = error_vows(pos,vow_pos) + 1;
                end
                n_vows(pos,vow_pos) = n_vows(pos,vow_pos) + 1;
            else
                con_pos = find(strcmp(data(trial).tgt1,CONS));
                if data(trial).score == 0
                    error_cons(pos,con_pos) = error_cons(pos,con_pos) + 1;
                end
                n_cons(pos,con_pos) = n_cons(pos,con_pos) + 1;
            end
        else
            pos = 2; % final postion changed
            % VOW in final position?
            vow_pos = find(strcmp(data(trial).tgt1,VOWS));
            if  ~isempty(vow_pos)
                if data(trial).score == 0
                    error_vows(pos,vow_pos) = error_vows(pos,vow_pos) + 1;
                end
                n_vows(pos,vow_pos) = n_vows(pos,vow_pos) + 1;
            else
                con_pos = find(strcmp(data(trial).tgt1,CONS));
                if data(trial).score == 0
                    error_cons(pos,con_pos) = error_cons(pos,con_pos) + 1;
                end
                n_cons(pos,con_pos) = n_cons(pos,con_pos) + 1;
            end
        end
    end
    
    pe_cons = error_cons ./ n_cons;
    pe_cons(3:4,:) = bsxfun(@gt, n_cons, Nt); % add flags for number of trails
    
    pe_vows = error_vows ./ n_vows;
    pe_vows(3:4,:) = bsxfun(@gt, n_vows, Nt);
    
    pe_allsbjs{1,sbj}=pe_vows;
    pe_allsbjs{2,sbj}=pe_cons;
end

legend_rd={};
legend_rc={};

figure(1); % vowel inital plot
hvi = tight_subplot(2,2,[.01 .03],[.1 .05],[.1 .01]);
figure(2); % vowel final plot
hvf = tight_subplot(2,2,[.01 .03],[.1 .05],[.1 .01]);
figure(3); % cons inital plot
hci = tight_subplot(2,2,[.01 .03],[.1 .05],[.1 .01]);
figure(4); % cons final plot
hcf = tight_subplot(2,2,[.01 .03],[.1 .05],[.1 .01]);

for sbj = 1 : length(SBJS)
    % exclude Lucas and Savannah
    if sum(strcmp(SBJS{sbj},{'Lucas','Savannah'}))
        continue
    end
    if isempty(find(strcmp(SBJS{sbj},READING_DISABLED)))
        subfig = 1;
        line_type = '-';
        %legend_rc = {legend_rc{:} SBJS{sbj}};
    else
        subfig = 2;
        line_type = '-';
        %legend_rd = {legend_rd{:} SBJS{sbj}};
    end
    
    % vowel inital plot
    pe_list = pe_allsbjs{1,sbj};
    nl_tr = pe_list(3,:)==1; % indexs with large enough trials
    pe_list_sort= sort(pe_list(1,nl_tr));
    axes(hvi(subfig)); hold on;
    plot(pe_list_sort,line_type,'color',Colors(sbj,:)./255,'DisplayName',SBJS{sbj})
    % plot for fewer trials
    axes(hvi(subfig+2)); hold on;
    pe_list_sort= sort(pe_list(1,~nl_tr));
    plot(pe_list_sort,line_type,'color',Colors(sbj,:)./255,'DisplayName',SBJS{sbj})
    
    % vowel final plot
    nl_tr = pe_list(4,:)==1; % indexs with large enough trials
    pe_list_sort = sort(pe_list(2,nl_tr));
    axes(hvf(subfig)); hold on;
    plot(pe_list_sort,line_type,'color',Colors(sbj,:)./255,'DisplayName',SBJS{sbj});
    axes(hvf(subfig+2)); hold on;
    pe_list_sort= sort(pe_list(2,~nl_tr));
    plot(pe_list_sort,line_type,'color',Colors(sbj,:)./255,'DisplayName',SBJS{sbj});
    
    % cons intitial
    pe_list = pe_allsbjs{2,sbj};
    nl_tr = pe_list(3,:)==1; % indexs with large enough trials
    pe_list_sort = sort(pe_list(1,nl_tr));
    axes(hci(subfig)); hold on;
    plot(pe_list_sort,line_type,'color',Colors(sbj,:)./255,'DisplayName',SBJS{sbj})
    axes(hci(subfig+2)); hold on;
    pe_list_sort= sort(pe_list(1,~nl_tr));
    plot(pe_list_sort,line_type,'color',Colors(sbj,:)./255,'DisplayName',SBJS{sbj});
    
    % cons final
    nl_tr = pe_list(4,:)==1; % indexs with large enough trials
    pe_list_sort = sort(pe_list(2,nl_tr));
    axes(hcf(subfig)); hold on;
    plot(pe_list_sort,line_type,'color',Colors(sbj,:)./255,'DisplayName',SBJS{sbj});
    axes(hcf(subfig+2)); hold on;
    pe_list_sort = sort(pe_list(2,~nl_tr));
    plot(pe_list_sort,line_type,'color',Colors(sbj,:)./255,'DisplayName',SBJS{sbj});
    
end

% formating of figures
figure(1)
annotation(figure(1),'textbox',...
    [0.45 0.95 0.2 0.06],...
    'String',{'Vowels Initial'},...
    'FontSize',14,...
    'LineStyle','none');
axes(hvi(1));
axis tight
title('Reading Controls')
ylim([0 1])
%axes(hvi(3));
%legend(legend_rc,'Location','EastOutside','FontSize',8,'EdgeColor',[1 1 1])
legend(hvi(1),'show','Location','EastOutside')
axes(hvi(2));
axis tight
title('Reading Disabled')
ylim([0 1])
%axes(hvi(4));
%legend(legend_rd,'Location','EastOutside','FontSize',8,'EdgeColor',[1 1 1])
legend(hvi(2),'show','Location','EastOutside')
axes(hvi(3));
axis tight
legend(hvi(3),'show','Location','EastOutside')
ylim([0 1])
axes(hvi(4));
axis tight
legend(hvi(4),'show','Location','EastOutside')
ylim([0 1])
legendshrink(0.4)
fname = sprintf('vowels_initial.eps'); % figure name
print(gcf, fullfile('fig', fname), '-depsc2'); % save stacked barplot

figure(2)
annotation(figure(2),'textbox',...
    [0.45 0.95 0.2 0.06],...
    'String',{'Vowels Final'},...
    'FontSize',14,...
    'LineStyle','none');
axes(hvf(1));
axis tight
title('Reading Controls')
%legend(legend_rc,'Location','EastOutside','FontSize',8,'EdgeColor',[1 1 1])
legend(hvf(1),'show','Location','EastOutside')
ylim([0 1])
axes(hvf(2));
axis tight
title('Reading Disabled')
%legend(legend_rd,'Location','EastOutside','FontSize',8,'EdgeColor',[1 1 1])
legend(hvf(2),'show','Location','EastOutside')
ylim([0 1])
axes(hvf(3));
axis tight
legend(hvf(3),'show','Location','EastOutside')
ylim([0 1])
axes(hvf(4));
axis tight
legend(hvf(4),'show','Location','EastOutside')
ylim([0 1])
legendshrink(0.4)
fname = sprintf('vowels_final.eps'); % figure name
print(gcf, fullfile('fig', fname), '-depsc2'); % save stacked barplot

figure(3)
annotation(figure(3),'textbox',...
    [0.4 0.95 0.3 0.06],...
    'String',{'Consonants Initial'},...
    'FontSize',14,...
    'LineStyle','none');
axes(hci(1));
axis tight
title('Reading Controls')
%legend(legend_rc,'Location','EastOutside','FontSize',8,'EdgeColor',[1 1 1])
legend(hci(1),'show','Location','EastOutside')
ylim([0 1])
axes(hci(2));
axis tight
title('Reading Disabled')
%legend(legend_rd,'Location','EastOutside','FontSize',8,'EdgeColor',[1 1 1])
legend(hci(2),'show','Location','EastOutside')
ylim([0 1])
axes(hci(3));
axis tight
legend(hci(3),'show','Location','EastOutside')
ylim([0 1])
axes(hci(4));
axis tight
legend(hci(4),'show','Location','EastOutside')
ylim([0 1])
legendshrink(0.4)
fname = sprintf('cons_initial.eps'); % figure name
print(gcf, fullfile('fig', fname), '-depsc2'); % save stacked barplot

figure(4)
annotation(figure(4),'textbox',...
    [0.4 0.95 0.3 0.06],...
    'String',{'Consonants Final'},...
    'FontSize',14,...
    'LineStyle','none');
axes(hcf(1));
axis tight
title('Reading Controls')
legend(hcf(1),'show','Location','EastOutside')
ylim([0 1])
axes(hcf(2));
axis tight
title('Reading Disabled')
legend(hcf(2),'show','Location','EastOutside')
ylim([0 1])
axes(hcf(3));
axis tight
legend(hcf(3),'show','Location','EastOutside')
ylim([0 1])
axes(hcf(4));
axis tight
legend(hcf(4),'show','Location','EastOutside')
ylim([0 1])
legendshrink(0.4)

fname = sprintf('cons_final.eps'); % figure name
print(gcf, fullfile('fig', fname), '-depsc2'); % save stacked barplot
