% Calculate Sorted error plots for SCO data
clc;clear all; close all;
symbols = {'@', 'A', 'C', 'D', 'E', 'G', 'I', 'J', 'O', 'R', 'S', 'T', 'U',...
    'W', 'Y', 'Z', 'a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i', 'k', 'l',...
    'm', 'n', 'o', 'p', 'r', 's', 't', 'u', 'v', 'w', 'y', 'z'}

CONS = {'C','D','G','J','S','T','Z','b','d','f','g','h','k','l','m','n','p','r','s','t','v','w','y','z'};
VOWS = {'@','A','E','I','O','R','U','W','Y','a','c','e','i','o','u'};
READING_DISABLED = {'Alina','Angela','Edward','Latisha','Laura','Matt','Norene','Shauna','Tina','Teddy','Tony'};

Nt = 2; % threshold for number of trails


addpath ../bin
addpath ./bin
Colors=setAndreaColors;

% get usbject names
d=dir('../*.mat')

for sbj = 1 : length(d)
    mat_name = d(sbj).name
    load(['../' mat_name]);
    SBJS{1,sbj} =  mat_name(6:length(mat_name)-4);
    
    error_cons = zeros(2,length(CONS));
    n_cons = zeros(2,length(CONS));
    error_vows = zeros(2,length(VOWS));
    n_vows = zeros(2,length(VOWS));
    
    for trial = 1 : length(data)
        if strcmp(data(trial).tgt1,'Q')
            data(trial).tgt1 = '@';
        end
        if strcmp(data(trial).tgt2,'Q')
            data(trial).tgt2 = '@';
        end
        if strcmp(data(trial).msk1,'Q')
            data(trial).msk1 = '@';
        end
        if strcmp(data(trial).msk2,'Q')
            data(trial).msk2 = '@';
        end
        
        
        % Was first or second sound changed?
        if ~strcmp(data(trial).tgt1,data(trial).msk1)
            pos = 1; % inital was changed
            % VOW in inital position?
            vow_pos = find(strcmp(data(trial).tgt1,VOWS));
            con_pos = find(strcmp(data(trial).tgt1,CONS));
            if  ~isempty(vow_pos)
                if data(trial).score == 0
                    error_vows(pos,vow_pos) = error_vows(pos,vow_pos) + 1;
                end
                n_vows(pos,vow_pos) = n_vows(pos,vow_pos) + 1;
            elseif ~isempty(con_pos)
                con_pos = find(strcmp(data(trial).tgt1,CONS));
                if data(trial).score == 0
                    error_cons(pos,con_pos) = error_cons(pos,con_pos) + 1;
                end
                n_cons(pos,con_pos) = n_cons(pos,con_pos) + 1;
            else
                disp(['something is fishy with ' data(trial).tgt1 ' in initial position in trial ' num2str(trial)]);
            end
        elseif ~strcmp(data(trial).tgt2,data(trial).msk2)
            pos = 2; % final postion changed
            % VOW in final position?
            vow_pos = find(strcmp(data(trial).tgt2,VOWS));
            con_pos = find(strcmp(data(trial).tgt2,CONS));
            if  ~isempty(vow_pos)
                if data(trial).score == 0
                    error_vows(pos,vow_pos) = error_vows(pos,vow_pos) + 1;
                end
                n_vows(pos,vow_pos) = n_vows(pos,vow_pos) + 1;
            elseif ~isempty(con_pos)
                if data(trial).score == 0
                    error_cons(pos,con_pos) = error_cons(pos,con_pos) + 1;
                end
                n_cons(pos,con_pos) = n_cons(pos,con_pos) + 1;
            else
                disp(['something is fishy with ' data(trial).tgt2 ' in final position in trial ' num2str(trial)]);
            end
        else
            disp(['something is fishy ' num2str(trial)]);
        end
    end
    
    pe_cons = error_cons ./ n_cons;
    pe_cons(isnan(pe_cons)) = 0;
    [M V] = binostat(n_cons,pe_cons);
    pe_cons(3:4,:) = bsxfun(@gt, n_cons, Nt); % add flags for number of trails
    pe_cons(5:6,:) = V;
    pe_cons(7:8,:) = n_cons;
    
    
    pe_vows = error_vows ./ n_vows;
    pe_vows(isnan(pe_vows)) = 0;
    [M V] = binostat(n_vows,pe_vows(1:2,:));
    pe_vows(3:4,:) = bsxfun(@gt, n_vows, Nt);
    pe_vows(5:6,:) = V;
    pe_vows(7:8,:) = n_vows;
    
    pe_allsbjs{1,sbj}=pe_vows;
    pe_allsbjs{2,sbj}=pe_cons;
end
%% Plot
figure(1); % vowel inital plot
hvi = tight_subplot(2,1,[.01 .03],[.1 .05],[.1 .01]);
figure(2); % vowel final plot
hvf = tight_subplot(2,1,[.01 .03],[.1 .05],[.1 .01]);
figure(3); % cons inital plot
hci = tight_subplot(2,1,[.01 .03],[.1 .05],[.1 .01]);
figure(4); % cons final plot
hcf = tight_subplot(2,1,[.01 .03],[.1 .05],[.1 .01]);

for sbj = 1 : length(SBJS)
    % exclude Lucas and Savannah
    if sum(strcmp(SBJS{sbj},{'Lucas','Savannah'}))
        continue
    end
    if isempty(find(strcmp(SBJS{sbj},READING_DISABLED)))
        subfig = 1;
        line_type = '-';
        %legend_rc = {legend_rc{:} SBJS{sbj}};
    else
        subfig = 2;
        line_type = '-';
        %legend_rd = {legend_rd{:} SBJS{sbj}};
    end
    std_scaling = 125;
    
    % vowel inital plot
    pe_list = pe_allsbjs{1,sbj};
    % nl_tr = pe_list(3,:)==1; % indexs with large enough trials
    [pe_list_sort indx]= sort(pe_list(1,:));
    axes(hvi(subfig)); hold on;
    %plot(pe_list_sort,line_type,'color',Colors(sbj,:)./255,'DisplayName',SBJS{sbj})
    x = 1:length(pe_list_sort);
    std = sqrt(pe_list(5,indx))./std_scaling;
    z1 = pe_list_sort+std;
    z2 = pe_list_sort-std;
    jbfill(x,z1,z2,Colors(sbj,:)./255,Colors(sbj,:)./255,1,1,SBJS{sbj}); 
    
    % vowel final plot
    [pe_list_sort indx]= sort(pe_list(2,:));
    axes(hvf(subfig)); hold on;
    %plot(pe_list_sort,line_type,'color',Colors(sbj,:)./255,'DisplayName',SBJS{sbj});
    std = sqrt(pe_list(6,indx))./std_scaling;
    z1 = pe_list_sort+std;
    z2 = pe_list_sort-std;
    jbfill(x,z1,z2,Colors(sbj,:)./255,Colors(sbj,:)./255,1,1,SBJS{sbj}); 
    
    % cons intitial
    pe_list = pe_allsbjs{2,sbj};
    [pe_list_sort indx] = sort(pe_list(1,:));
    axes(hci(subfig)); hold on;
    %plot(pe_list_sort,line_type,'color',Colors(sbj,:)./255,'DisplayName',SBJS{sbj})
    x = 1:length(pe_list_sort);
    std = sqrt(pe_list(5,indx))./std_scaling;
    z1 = pe_list_sort+std;
    z2 = pe_list_sort-std;
    jbfill(x,z1,z2,Colors(sbj,:)./255,Colors(sbj,:)./255,1,1,SBJS{sbj});
    
    % cons final
    [pe_list_sort indx] = sort(pe_list(2,:));
    axes(hcf(subfig)); hold on;
    %plot(pe_list_sort,line_type,'color',Colors(sbj,:)./255,'DisplayName',SBJS{sbj});
    std = sqrt(pe_list(6,indx))./std_scaling;
    z1 = pe_list_sort+std;
    z2 = pe_list_sort-std;
    jbfill(x,z1,z2,Colors(sbj,:)./255,Colors(sbj,:)./255,1,1,SBJS{sbj});
    
end

% formating of figures
hf = figure(1)
annotation(figure(1),'textbox',...
    [0.45 0.95 0.2 0.06],...
    'String',{'Vowels Initial'},...
    'FontSize',14,...
    'LineStyle','none');
axes(hvi(1));
axis tight
%title('Reading Controls')
% Create titles
annotation(hf,'textbox',...
    [0.35 0.44 0.08 0.04],...
    'String',{'Reading Disabled'},'FitBoxToTex','on','FitHeightToText','on','EdgeColor','none','HorizontalAlignment','center');
annotation(hf,'textbox',...
    [0.35 0.88 0.08 0.04],...
    'String',{'Reading Controls'},'FitBoxToTex','on','FitHeightToText','on','EdgeColor','none','HorizontalAlignment','center');;
ylim([0 1])
%axes(hvi(3));
%legend(legend_rc,'Location','EastOutside','FontSize',8,'EdgeColor',[1 1 1])
legend(hvi(1),'show','Location','EastOutside')
axes(hvi(2));
axis tight
%title('Reading Disabled')
ylim([0 1])
%axes(hvi(4));
%legend(legend_rd,'Location','EastOutside','FontSize',8,'EdgeColor',[1 1 1])
legend(hvi(2),'show','Location','EastOutside')
% axes(hvi(3));
% axis tight
% legend(hvi(3),'show','Location','EastOutside')
% ylim([0 1])
% axes(hvi(4));
% axis tight
% legend(hvi(4),'show','Location','EastOutside')
% ylim([0 1])
%legendshrink(0.4)
fname = sprintf('vowelsInitial.eps'); % figure name
print(gcf, fullfile('fig', fname), '-depsc2'); % save stacked barplot

hf = figure(2)
annotation(figure(2),'textbox',...
    [0.45 0.95 0.2 0.06],...
    'String',{'Vowels Final'},...
    'FontSize',14,...
    'LineStyle','none');
axes(hvf(1));
axis tight
%title('Reading Controls')
% Create titles
annotation(hf,'textbox',...
    [0.35 0.44 0.08 0.04],...
    'String',{'Reading Disabled'},'FitBoxToTex','on','FitHeightToText','on','EdgeColor','none','HorizontalAlignment','center');
annotation(hf,'textbox',...
    [0.35 0.88 0.08 0.04],...
    'String',{'Reading Controls'},'FitBoxToTex','on','FitHeightToText','on','EdgeColor','none','HorizontalAlignment','center');
%legend(legend_rc,'Location','EastOutside','FontSize',8,'EdgeColor',[1 1 1])
legend(hvf(1),'show','Location','EastOutside')
ylim([0 1])
axes(hvf(2));
axis tight
%title('Reading Disabled')
%legend(legend_rd,'Location','EastOutside','FontSize',8,'EdgeColor',[1 1 1])
legend(hvf(2),'show','Location','EastOutside')
ylim([0 1])
% axes(hvf(3));
% axis tight
% legend(hvf(3),'show','Location','EastOutside')
% ylim([0 1])
% axes(hvf(4));
% axis tight
% legend(hvf(4),'show','Location','EastOutside')
% ylim([0 1])
%legendshrink(0.4)
fname = sprintf('vowelsFinal.eps'); % figure name
print(gcf, fullfile('fig', fname), '-depsc2'); % save stacked barplot

hf = figure(3)
annotation(figure(3),'textbox',...
    [0.4 0.95 0.3 0.06],...
    'String',{'Consonants Initial'},...
    'FontSize',14,...
    'LineStyle','none');
axes(hci(1));
axis tight
%title('Reading Controls')
% Create titles
annotation(hf,'textbox',...
    [0.35 0.44 0.08 0.04],...
    'String',{'Reading Disabled'},'FitBoxToTex','on','FitHeightToText','on','EdgeColor','none','HorizontalAlignment','center');
annotation(hf,'textbox',...
    [0.35 0.88 0.08 0.04],...
    'String',{'Reading Controls'},'FitBoxToTex','on','FitHeightToText','on','EdgeColor','none','HorizontalAlignment','center');
%legend(legend_rc,'Location','EastOutside','FontSize',8,'EdgeColor',[1 1 1])
legend(hci(1),'show','Location','EastOutside')
ylim([0 1])
axes(hci(2));
axis tight
%title('Reading Disabled')
%legend(legend_rd,'Location','EastOutside','FontSize',8,'EdgeColor',[1 1 1])
legend(hci(2),'show','Location','EastOutside')
ylim([0 1])
% axes(hci(3));
% axis tight
% legend(hci(3),'show','Location','EastOutside')
% ylim([0 1])
% axes(hci(4));
% axis tight
% legend(hci(4),'show','Location','EastOutside')
% ylim([0 1])
%legendshrink(0.4)
fname = sprintf('consInitial.eps'); % figure name
print(gcf, fullfile('fig', fname), '-depsc2'); % save stacked barplot

hf = figure(4)
annotation(figure(4),'textbox',...
    [0.4 0.95 0.3 0.06],...
    'String',{'Consonants Final'},...
    'FontSize',14,...
    'LineStyle','none');
axes(hcf(1));
axis tight
%title('Reading Controls')
% Create titles
annotation(hf,'textbox',...
    [0.35 0.44 0.08 0.04],...
    'String',{'Reading Disabled'},'FitBoxToTex','on','FitHeightToText','on','EdgeColor','none','HorizontalAlignment','center');
annotation(hf,'textbox',...
    [0.35 0.88 0.08 0.04],...
    'String',{'Reading Controls'},'FitBoxToTex','on','FitHeightToText','on','EdgeColor','none','HorizontalAlignment','center');
legend(hcf(1),'show','Location','EastOutside')
ylim([0 1])
axes(hcf(2));
axis tight
%title('Reading Disabled')
legend(hcf(2),'show','Location','EastOutside')
ylim([0 1])
% axes(hcf(3));
% axis tight
% legend(hcf(3),'show','Location','EastOutside')
% ylim([0 1])
% axes(hcf(4));
% axis tight
% legend(hcf(4),'show','Location','EastOutside')
% ylim([0 1])
%legendshrink(0.4)

fname = sprintf('consFinal.eps'); % figure name
print(gcf, fullfile('fig', fname), '-depsc2'); % save stacked barplot
